@@ -10,7 +10,9 @@ from pathlib import Path
 from typing import Optional
 
 import pandas as pd 
-import keras as kr
+
+os.environ["CUDA_VISIBLE_DEVICES"] = "-1" # Disable using GPU
+from tensorflow import keras as kr
 
 #-------------------------------------------------------------
 # First define/init some general variables/constants
